```{eval-rst}
.. module:: xncml

```

# Xncml Documentation

`xncml` adds NcML support to xarray. It includes utilities to modify NcML documents, and open NcML files as `xarray.Dataset`. For more information on NcML, take a look at [tutorials and examples](https://docs.unidata.ucar.edu/netcdf-java/current/userguide/basic_ncml_tutorial.html) and the [annotated schema](https://docs.unidata.ucar.edu/netcdf-java/current/userguide/annotated_ncml_schema.html).

## Installing

`xncml` can be installed from PyPI with pip:

```bash
pip install xncml
```

## Contents

```{toctree}
:maxdepth: 2

tutorial
```

## Meta

- [Changelog](changelog.md)
- [Github](https://github.com/xarray-contrib/xncml/)

Note the existence of a similar [project](https://github.com/ioos/ncml) to edit NcML documents, now archived.


## Feedback

If you encounter any errors or problems with **xncml**,
please open an Issue at the GitHub <http://github.com/xarray-contrib/xncml> main repository.
